package envoy.client.ui.listcell;

import javafx.scene.Cursor;
import javafx.scene.Node;
import javafx.scene.control.ContentDisplay;
import javafx.scene.control.ListCell;
import javafx.scene.control.ListView;

/**
 * Provides a convenience frame for list cell creation.
 * <p>
 * Project: <strong>envoy-client</strong><br>
 * File: <strong>AbstractListCell.java</strong><br>
 * Created: <strong>18.07.2020</strong><br>
 *
 * @author Kai S. K. Engelbart
 * @param <T> the type of element displayed by the list cell
 * @param <U> the type of node as which the list element will be displayed
 * @since Envoy Client v0.1-beta
 */
public abstract class AbstractListCell<T, U extends Node> extends ListCell<T> {

	protected ListView<? extends T> listView;

	/**
	 * @param listView the list view inside of which the cell will be displayed
	 * @since Envoy Client v0.1-beta
	 */
	public AbstractListCell(ListView<? extends T> listView) {
		this.listView = listView;
		setContentDisplay(ContentDisplay.GRAPHIC_ONLY);
		getStyleClass().add("list-element");
	}

	@Override
	protected final void updateItem(T item, boolean empty) {
		super.updateItem(item, empty);
		if (!(empty || item == null)) {
			setCursor(Cursor.HAND);
			setGraphic(renderItem(item));
		} else {
			setGraphic(null);
		}
	}

	/**
	 * Converts a list item to a node. This can have side effects on the list cell.
	 *
	 * @param item the item to render
	 * @return a node representing the item
	 * @since Envoy Client v0.1-beta
	 */
	protected abstract U renderItem(T item);
}
