package envoy.event;

/**
 * This event should be sent when a user is currently typing something in a
 * chat.
 * <p>
 * Project: <strong>envoy-client</strong><br>
 * File: <strong>IsTyping.java</strong><br>
 * Created: <strong>24.07.2020</strong><br>
 *
 * @author Leon Hofmeister
 * @since Envoy Client v0.2-beta
 */
public final class IsTyping extends Event<Long> {

	private final long destinationID;

	private static final long serialVersionUID = 1L;

	/**
	 * The number of milliseconds that this event will be active.<br>
	 * Currently set to 3.5 seconds.
	 *
	 * @since Envoy Common v0.2-beta
	 */
	public static final int millisecondsActive = 3500;

	/**
	 * Creates a new {@code IsTyping} event with originator and recipient.
	 *
	 * @param sourceID      the id of the originator
	 * @param destinationID the id of the contact the user wrote to
	 * @since Envoy Common v0.2-beta
	 */
	public IsTyping(Long sourceID, long destinationID) {
		super(sourceID);
		this.destinationID = destinationID;
	}

	/**
	 * @return the id of the contact in whose chat the user typed something
	 * @since Envoy Common v0.2-beta
	 */
	public long getDestinationID() { return destinationID; }
}
