package envoy.event;

/**
 * This class allows envoy users to send an issue proposal to the server who, if
 * not disabled by its admin, will forward it directly to gitea.
 * <p>
 * Project: <strong>common</strong><br>
 * File: <strong>IssueProposal.java</strong><br>
 * Created: <strong>05.08.2020</strong><br>
 *
 * @author Leon Hofmeister
 * @since Envoy Common v0.2-beta
 */
public final class IssueProposal extends Event<String> {

	private final String	description;
	private final boolean	bug;

	private static final long serialVersionUID = 1L;

	/**
	 * @param title       the title of the reported bug
	 * @param description the description of this bug
	 * @param isBug       determines whether this {@code IssueProposal} is
	 *                    supposed to be a
	 *                    feature or a bug (true = bug, false = feature)
	 * @since Envoy Common v0.2-beta
	 */
	public IssueProposal(String title, String description, boolean isBug) {
		super(title);
		this.description	= description;
		bug					= isBug;
	}

	/**
	 * @return the description
	 * @since Envoy Common v0.2-beta
	 */
	public String getDescription() { return description; }

	/**
	 * @return whether this issue is supposed to be a bug - otherwise it is intended
	 *         as a feature
	 * @since Envoy Common v0.2-beta
	 */
	public boolean isBug() { return bug; }
}
