package envoy.event.contact;

import envoy.data.Contact;
import envoy.event.ElementOperation;
import envoy.event.Event;

/**
 * Signifies the modification of a contact list.<br>
 * <br>
 * Project: <strong>envoy-common</strong><br>
 * File: <strong>ContactOperation.java</strong><br>
 * Created: <strong>05.02.2020</strong><br>
 *
 * @author Maximilian K&auml;fer
 * @since Envoy Common v0.2-alpha
 */
public final class ContactOperation extends Event<Contact> {

	private final ElementOperation operationType;

	private static final long serialVersionUID = 1L;

	/**
	 * Initializes a {@link ContactOperation}.
	 *
	 * @param contact       the user on which the operation is performed
	 * @param operationType the type of operation to perform
	 * @since Envoy Common v0.2-alpha
	 */
	public ContactOperation(Contact contact, ElementOperation operationType) {
		super(contact);
		this.operationType = operationType;
	}

	/**
	 * @return the type of operation to perform
	 * @since Envoy Common v0.2-alpha
	 */
	public ElementOperation getOperationType() { return operationType; }
}
